pub enum PacketData {
Plaintext(String),
Binary(Bytes),
Empty,
}Expand description
Use this enum to figure out if a packet in a payload has binary or string data. In string-encoded payloads, each packet may contain string or binary data. Binary data in string-encoded payloads is encoded to base64. Otherwise, string data is returned as is. In binary-encoded payloads, each packet may contain string or binary data. If a packet in a payload has string data, it’s parsed as a UTF-8 string.
Variants